---
icon: material/application-brackets
title: OME-Zarr Explorer
hide:
    - toc
instanthtml: false
---

???+ question "What is this?"
    This educational app demonstrates how various OME-NGFF zarr hierarchies are
    structured, along with associated metadata.

    - Define your image dimensions and view the generated hierarchy and metadata in real-time.
    - The file tree on the left demonstrates what the OME-Zarr hierarchy would look like when saved to disk
    - The **`Spec JSON`** tab shows the metadata associated with each group or array
    - The **`Python`** tab shows how you would create the metadata programmatically using the `yaozarrs` library.

    **This is meant for educational purposes only and is not intended for production use.**

<ome-explorer></ome-explorer>
